@@ -11,7 +11,7 @@ use Sub::Util qw(set_subname);
 use B qw(perlstring);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 
 sub import {
 	my $class  = shift;
@@ -23,7 +23,7 @@ sub setup_for {
 	my $class = shift;
 	my ($target) = @_;
 	
-	my $orig = $Moo::MAKERS{$target}{exports}{has}
+	my $orig = $Moo::MAKERS{$target}{exports}{has} || $Moo::MAKERS{$target}{non_methods}{has}
 		or croak("$target doesn't have a `has` function");
 	
 	Moo::_install_tracked $target, has => sub {
